@@ -34,8 +34,8 @@ import org.dashbuilder.dataset.DataSetOpType;
 import org.dashbuilder.dataset.client.DataSetReadyCallback;
 import org.dashbuilder.dataset.filter.*;
 import org.dashbuilder.dataset.sort.SortOrder;
+import org.jboss.errai.bus.client.api.messaging.Message;
 import org.jboss.errai.common.client.api.Caller;
-import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.jbpm.workbench.common.client.PerspectiveIds;
 import org.jbpm.workbench.common.client.filters.active.ActiveFilterItem;
@@ -44,11 +44,13 @@ import org.jbpm.workbench.common.client.list.MultiGridView;
 import org.jbpm.workbench.common.client.menu.RefreshMenuBuilder;
 import org.jbpm.workbench.df.client.filter.FilterSettings;
 import org.jbpm.workbench.df.client.list.DataSetQueryHelper;
+import org.jbpm.workbench.ht.client.editors.taskslist.popup.TasksReassignmentPresenter;
 import org.jbpm.workbench.ht.client.resources.i18n.Constants;
 import org.jbpm.workbench.ht.model.TaskSummary;
 import org.jbpm.workbench.ht.model.events.*;
 import org.jbpm.workbench.ht.service.TaskService;
 import org.jbpm.workbench.ht.util.TaskStatus;
+import org.kie.api.runtime.process.ProcessInstance;
 import org.uberfire.client.workbench.events.BeforeClosePlaceEvent;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
@@ -58,7 +60,6 @@ import org.uberfire.workbench.model.menu.Menus;
 import static org.dashbuilder.dataset.filter.FilterFactory.*;
 import static org.jbpm.workbench.common.client.util.DataSetUtils.*;
 import static org.jbpm.workbench.ht.model.TaskDataSetConstants.*;
-import static org.jbpm.workbench.pr.model.ProcessInstanceDataSetConstants.COLUMN_STATUS;
 
 public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresenter.TaskListView> extends AbstractMultiGridPresenter<TaskSummary, V> {
 
@@ -100,7 +101,7 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
         return errorHandlerBuilder.get().withUUID(tableSettings.getUUID()).withDataSetCallback(
                 dataSet -> {
                     if (dataSet != null && dataSetQueryHelper.getCurrentTableSettings().getKey().equals(tableSettings.getKey())) {
-                        final List<TaskSummary> myTasksFromDataSet = new ArrayList<TaskSummary>();
+                        final List<TaskSummary> myTasksFromDataSet = new ArrayList<>();
 
                         for (int i = 0; i < dataSet.getRowCount(); i++) {
                             myTasksFromDataSet.add(new TaskSummaryDataSetMapper().apply(dataSet,
@@ -114,6 +115,9 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
 
                         List<DataSetOp> ops = tableSettings.getDataSetLookup().getOperationList();
                         String filterValue = isFilteredByTaskName(ops); //Add here the check to add the domain data columns taskName?
+
+                        //RHPAM-4611 Tasks listed twice once completed in Business Central
+                        removeDuplicateTaskSummaryBySLAStatus(myTasksFromDataSet);
                         if (filterValue != null) {
                             getDomainSpecifDataForTasks(startRange,
                                                         myTasksFromDataSet,
@@ -130,6 +134,21 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
                 .withEmptyResultsCallback(() -> setEmptyResults());
     }
 
+    protected void removeDuplicateTaskSummaryBySLAStatus(List<TaskSummary> taskSummaries) {
+        Set<Long> duplicated = new HashSet<>();
+        Set<Long> ids = new HashSet<>();
+
+        for (TaskSummary taskSummary : taskSummaries) {
+            if (ids.contains(taskSummary.getId())) {
+                duplicated.add(taskSummary.getId());
+            }
+            ids.add(taskSummary.getId());
+        }
+
+        final Integer slaPending = Integer.valueOf(ProcessInstance.SLA_PENDING);
+        taskSummaries.removeIf(task -> slaPending.equals(task.getSlaCompliance()) && duplicated.contains(task.getId()));
+    }
+
     @Override
     protected void removeActiveFilter(final ColumnFilter columnFilter) {
         super.removeActiveFilter(columnFilter);
@@ -225,70 +244,71 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
     }
 
     public void releaseTask(final TaskSummary task) {
-        taskService.call(
-                new RemoteCallback<Void>() {
-                    @Override
-                    public void callback(Void nothing) {
-                        view.displayNotification(constants.TaskReleased(String.valueOf(task.getId())));
-                        refreshGrid();
-                    }
-                }).releaseTask(getSelectedServerTemplate(),
-                               task.getDeploymentId(),
-                               task.getId());
+        taskService.call((Void nothing) -> {
+            view.displayNotification(constants.TaskWasReleased(String.valueOf(task.getId()), task.getName()));
+                             refreshGrid();
+                         }, (Message message, Throwable throwable) -> {
+                             view.displayNotification(constants.UnableToReleaseTask(String.valueOf(task.getId()),
+                                                                                    task.getName(), throwable.getMessage()));
+                             return true;
+                         }
+        ).releaseTask(getSelectedServerTemplate(),
+                      task.getDeploymentId(),
+                      task.getId());
     }
 
     public void claimTask(final TaskSummary task) {
-        taskService.call(
-                new RemoteCallback<Void>() {
-                    @Override
-                    public void callback(Void nothing) {
-                        view.displayNotification(constants.TaskClaimed(String.valueOf(task.getId())));
-                        refreshGrid();
-                    }
-                }
+        taskService.call((Void nothing) -> {
+            view.displayNotification(constants.TaskWasClaimed(String.valueOf(task.getId()), task.getName()));
+                             refreshGrid();
+                         }, (Message message, Throwable throwable) -> {
+                             view.displayNotification(constants.UnableToClaimTask(String.valueOf(task.getId()),
+                                                                                  task.getName(), throwable.getMessage()));
+                             return true;
+                         }
         ).claimTask(getSelectedServerTemplate(),
                     task.getDeploymentId(),
                     task.getId());
     }
 
     public void claimAndWorkTask(final TaskSummary task) {
-        taskService.call(
-                new RemoteCallback<Void>() {
-                    @Override
-                    public void callback(Void nothing) {
-                        view.displayNotification(constants.TaskClaimed(String.valueOf(task.getId())));
-                        selectSummaryItem(task);
-                        refreshGrid();
-                    }
-                }
+        taskService.call((Void nothing) -> {
+            view.displayNotification(constants.TaskWasClaimed(String.valueOf(task.getId()), task.getName()));
+                             selectSummaryItem(task);
+                             refreshGrid();
+                         }, (Message message, Throwable throwable) -> {
+                             view.displayNotification(constants.UnableToClaimTask(String.valueOf(task.getId()),
+                                                                                  task.getName(), throwable.getMessage()));
+                             return true;
+                         }
         ).claimTask(getSelectedServerTemplate(),
                     task.getDeploymentId(),
                     task.getId());
     }
 
     public void resumeTask(final TaskSummary task) {
-        taskService.call(
-                new RemoteCallback<Void>() {
-                    @Override
-                    public void callback(Void nothing) {
-                        view.displayNotification(constants.TaskResumed(String.valueOf(task.getId())));
-                        refreshGrid();
-                    }
-                }
+        taskService.call((Void nothing) -> {
+            view.displayNotification(constants.TaskWasResumed(String.valueOf(task.getId()), task.getName()));
+                             refreshGrid();
+                         }, (Message message, Throwable throwable) -> {
+                             view.displayNotification(constants.UnableToResumeTask(String.valueOf(task.getId()),
+                                                                                   task.getName(), throwable.getMessage()));
+                             return true;
+                         }
         ).resumeTask(getSelectedServerTemplate(),
                      task.getDeploymentId(),
                      task.getId());
     }
 
     public void suspendTask(final TaskSummary task) {
-        taskService.call(
-                new RemoteCallback<Void>() {
-                    @Override
-                    public void callback(Void nothing) {
-                        view.displayNotification(constants.TaskSuspended(String.valueOf(task.getId())));
-                        refreshGrid();
-                    }
-                }
+        taskService.call((Void nothing) -> {
+            view.displayNotification(constants.TaskWasSuspended(String.valueOf(task.getId()), task.getName()));
+                             refreshGrid();
+                         }, (Message message, Throwable throwable) -> {
+                             view.displayNotification(constants.UnableToSuspendTask(String.valueOf(task.getId()),
+                                                                                    task.getName(), throwable.getMessage()));
+                             return true;
+                         }
         ).suspendTask(getSelectedServerTemplate(),
                       task.getDeploymentId(),
                       task.getId());
@@ -438,7 +458,9 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
 
     protected abstract Predicate<TaskSummary> getSuspendActionCondition();
 
-    protected abstract Predicate<TaskSummary> getResumeActionCondition();
+    protected Predicate<TaskSummary> getResumeActionCondition() {
+        return task -> TaskStatus.TASK_STATUS_SUSPENDED.equals(task.getTaskStatus());
+    }
 
     protected Predicate<TaskSummary> getCompleteActionCondition() {
         return task -> task.getActualOwner() != null && TaskStatus.TASK_STATUS_IN_PROGRESS.equals(task.getTaskStatus());
@@ -456,6 +478,85 @@ public abstract class AbstractTaskListPresenter<V extends AbstractTaskListPresen
         return task -> task.getProcessInstanceId() != null;
     }
 
+    public void bulkClaim(List<TaskSummary> taskSummaries) {
+        if (taskSummaries == null || taskSummaries.isEmpty()) {
+            return;
+        }
+        taskSummaries.forEach(taskSummary -> {
+            if (getClaimActionCondition().test(taskSummary)) {
+                claimTask(taskSummary);
+            } else {
+                view.displayNotification(
+                        constants.ClaimNotAllowedOn(String.valueOf(taskSummary.getId()), taskSummary.getName()));
+            }
+        });
+        deselectAllItems();
+    }
+
+    public void bulkRelease(List<TaskSummary> taskSummaries) {
+        if (taskSummaries == null || taskSummaries.isEmpty()) {
+            return;
+        }
+        taskSummaries.forEach(taskSummary -> {
+            if (getReleaseActionCondition().test(taskSummary)) {
+                releaseTask(taskSummary);
+            } else {
+                view.displayNotification(
+                        constants.ReleaseNotAllowedOn(String.valueOf(taskSummary.getId()), taskSummary.getName()));
+            }
+        });
+        deselectAllItems();
+    }
+
+    public void bulkResume(List<TaskSummary> taskSummaries) {
+        if (taskSummaries == null || taskSummaries.isEmpty()) {
+            return;
+        }
+        taskSummaries.forEach(taskSummary -> {
+            if (getResumeActionCondition().test(taskSummary)) {
+                resumeTask(taskSummary);
+            } else {
+                view.displayNotification(
+                        constants.ResumeNotAllowedOn(String.valueOf(taskSummary.getId()), taskSummary.getName()));
+            }
+        });
+        deselectAllItems();
+    }
+
+    public void bulkSuspend(List<TaskSummary> taskSummaries) {
+        if (taskSummaries == null || taskSummaries.isEmpty()) {
+            return;
+        }
+        taskSummaries.forEach(taskSummary -> {
+            if (getSuspendActionCondition().test(taskSummary)) {
+                suspendTask(taskSummary);
+            } else {
+                view.displayNotification(
+                        constants.SuspendNotAllowedOn(String.valueOf(taskSummary.getId()), taskSummary.getName()));
+            }
+        });
+        deselectAllItems();
+    }
+
+    public void bulkReassign(List<TaskSummary> taskSummaries) {
+        if (taskSummaries == null || taskSummaries.isEmpty()) {
+            return;
+        }
+
+        String taskIdsParam = taskSummaries.stream().map(s -> s.getId().toString()).collect(Collectors.joining(","));
+        String deploymentIdsParam = taskSummaries.stream().map(s -> s.getDeploymentId()).collect(Collectors.joining(","));
+
+        if (taskIdsParam.isEmpty()) {
+            return;
+        }
+        PlaceRequest placeRequestImpl = new DefaultPlaceRequest(TasksReassignmentPresenter.TASKS_REASSIGNMENT_POPUP);
+        placeRequestImpl.addParameter("taskIds", taskIdsParam);
+        placeRequestImpl.addParameter("deploymentIds", deploymentIdsParam);
+        placeRequestImpl.addParameter("serverTemplateId", getSelectedServerTemplate());
+
+        placeManager.goTo(placeRequestImpl);
+    }
+
     public interface TaskListView<T extends AbstractTaskListPresenter> extends MultiGridView<TaskSummary, T> {
 
         void addDomainSpecifColumns(Set<String> columns);
